@@ -7,43 +7,50 @@ use modeling::{by_dir, ClassInfo, ParseOption};
 use modeling::file_filter::FileFilter;
 use modeling::render::{MermaidRender, PlantUmlRender};
 use std::ffi::OsStr;
+use modeling::render::graphviz_render::GraphvizRender;
 
 #[derive(StructOpt, Debug, PartialEq, Clone)]
-#[structopt(name = "basic")]
+#[structopt(name = "Modeling")]
 struct Opts {
     /// merge for same method name
     #[structopt(short, long)]
     merge: bool,
-
     /// multiple modules
     #[structopt(short, long)]
     by_modules: bool,
-
     /// input dir
     #[structopt(short, long, default_value = ".")]
     input: String,
-
-    /// mermaid or puml
+    /// support: puml, mermaid, graphviz with json
     #[structopt(short, long, default_value = "puml")]
     output_type: String,
-
-    // filter dir
+    /// filter by packages, like: `com.phodal.modeling`
     #[structopt(long, short, use_delimiter = true)]
     packages: Vec<String>,
-
-    // filter suffixes
+    /// filter by suffixes, like: `java` for .java file
     #[structopt(long, short, use_delimiter = true)]
     suffixes: Vec<String>,
-
-    #[structopt(short)]
+    /// only load field in methods
+    #[structopt(short, long)]
     field_only: bool,
+    /// without class inheritance
+    #[structopt(short, long)]
+    without_parent: bool,
+    /// if class's field start with `IRepository` will become `Repository`
+    #[structopt(short, long)]
+    remove_impl_suffix: bool,
+    /// by grep regex rules: for example:
+    #[structopt(short, long, default_value = "")]
+    grep: String,
 }
 
 impl Opts {
     pub fn to_parse_option(&self) -> ParseOption {
         ParseOption {
             merge: self.merge,
-            field_only: self.field_only
+            field_only: self.field_only,
+            without_parent: self.without_parent,
+            remove_impl_suffix: self.remove_impl_suffix
         }
     }
 }
@@ -51,19 +58,15 @@ impl Opts {
 fn main() {
     let opts: Opts = Opts::from_args();
 
-    println!("Input path: {:?}", opts.input);
-    println!("packages: {:?}", opts.packages);
-    println!("suffixes: {:?}", opts.suffixes);
-
     let parse_option = opts.to_parse_option();
-    let filter = FileFilter::new(opts.packages.clone(), opts.suffixes.clone());
+    let filter = FileFilter::new(opts.packages.clone(), opts.suffixes.clone(), opts.grep.clone());
 
     if !opts.by_modules {
         output_all_in_one(opts, &parse_option, filter);
         return;
     }
 
-    for result in WalkBuilder::new("./").max_depth(Some(1)).build() {
+    for result in WalkBuilder::new(&opts.input).max_depth(Some(1)).build() {
         if let Ok(dir) = result {
             let path = dir.path();
             if path.is_dir() {
@@ -96,6 +99,11 @@ fn output_file(opts: &Opts, classes: &Vec<ClassInfo>, name: &str) {
             let file_name = format!("{}.mermaid", name);
             let _ = fs::write(file_name, uml);
         }
+        "graphviz" => {
+            let graph = GraphvizRender::render(&classes, &parse_option);
+            let file_name = format!("{}.dot", name);
+            let _ = fs::write(file_name, graph);
+        }
         &_ => {
             let uml = PlantUmlRender::render(&classes, &parse_option);
             let file_name = format!("{}.puml", name);
