@@ -21,6 +21,7 @@ pub mod render;
 pub mod coco_struct;
 pub mod file_filter;
 pub mod parse_option;
+pub mod segment;
 
 /// Returns Vec<ClassInfo> with the given path.
 ///
@@ -39,9 +40,7 @@ pub mod parse_option;
 /// let puml = PlantUmlRender::render(&classes, &ParseOption::default());
 /// ```
 pub fn by_dir<P: AsRef<Path>>(path: P, filter: FileFilter, option: &ParseOption) -> Vec<ClassInfo> {
-    let origin_files = files_from_path(path, filter);
-
-    by_files(origin_files, &option)
+    by_files(files_from_path(path, filter), &option)
 }
 
 /// Returns Vec<ClassInfo> with the given files.
@@ -108,6 +107,7 @@ fn files_from_path<P: AsRef<Path>>(path: P, filter: FileFilter) -> Vec<String> {
             }
         }
     }
+
     origin_files
 }
 
@@ -173,7 +173,7 @@ mod tests {
         let suffixes = vec!["store".to_string()];
 
         let option = ParseOption::default();
-        let vec = by_dir(path, FileFilter::new(vec![], suffixes), &option);
+        let vec = by_dir(path, FileFilter::new(vec![], suffixes, "".to_string()), &option);
 
         assert_eq!(3, vec.len());
         let result = PlantUmlRender::render(&vec, &option);
@@ -183,6 +183,22 @@ mod tests {
         assert!(result.contains("class classinfo_st"));
     }
 
+    #[test]
+    fn should_filter_by_grep() {
+        let root_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
+        let ctags_dir = root_dir.join("_fixtures")
+            .join("ctags")
+            .join("source");
+
+        let path = format!("{}", ctags_dir.display());
+
+        let option = ParseOption::default();
+        let filter = FileFilter::new(vec![], vec![], "store.go".to_string());
+        let vec = by_dir(path, filter, &option);
+
+        assert_eq!(3, vec.len());
+    }
+
     #[test]
     fn should_render_mermaid() {
         let path = format!("{}", ctags_fixtures_dir().display());
