@@ -20,7 +20,7 @@ impl MermaidRender {
         for clazz in classes {
             let mut dep_map: HashMap<String, String> = HashMap::default();
 
-            let members = render_member(&clazz, &mut dep_map, space);
+            let members = render_member(&clazz, &mut dep_map, space, parse_option);
             let mut methods = vec![];
             if !parse_option.field_only {
                 methods = render_method(&clazz, &mut dep_map, space);
@@ -28,7 +28,7 @@ impl MermaidRender {
 
             let content = format!("{}{}", members.join(""), methods.join(""));
             let class_field = clazz.name.clone();
-            if clazz.parents.len() > 0 {
+            if clazz.parents.len() > 0 && !parse_option.without_parent {
                 rendered.push(format!("{}{} <|-- {}", space, clazz.parents.join(","), clazz.name));
             }
 
